@@ -3,11 +3,13 @@
 {
     'name': 'Project Plan',
     'name_bg_BG': 'Планиране на проекти',
+    'name_ca_ES': 'Planificació de projectes',
     'name_de_DE': 'Projekte Planung',
+    'name_es_AR': 'Planificación de proyecto',
     'name_es_CO': 'Planeación de Proyectos',
     'name_es_ES': 'Planificación de proyecto',
     'name_fr_FR': 'Planification de projet',
-    'version': '2.2.1',
+    'version': '2.4.1',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -15,8 +17,12 @@
 ''',
     'description_bg_BG': '''Добавя възможност за планиране на проекти
 ''',
+    'description_ca_ES': '''Afegeix la capacitat de planificació de
+projectes.''',
     'description_de_DE': '''Projektmodul Planung:
     - Fügt Planungsmöglichkeiten für Projekte hinzu
+''',
+    'description_es_AR': '''Añade la capacidad de planificación de proyectos.
 ''',
     'description_es_CO': '''Añadir posibilidad de planeación de proyectos.
 ''',
@@ -36,7 +42,9 @@
     'translation': [
         'locale/cs_CZ.po',
         'locale/bg_BG.po',
+        'locale/ca_ES.po',
         'locale/de_DE.po',
+        'locale/es_AR.po',
         'locale/es_CO.po',
         'locale/es_ES.po',
         'locale/fr_FR.po',
