@@ -4,7 +4,7 @@ import datetime
 from collections import deque, defaultdict
 from heapq import heappop, heappush
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.wizard import Wizard
+from trytond.wizard import Wizard, StateTransition
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
 from trytond.pool import Pool
@@ -156,7 +156,6 @@ class Work(ModelSQL, ModelView):
                 leafs = next_leafs
             res['duration'] = durations
 
-
         fun_fields = ('early_start_date', 'early_finish_date',
                       'late_start_date', 'late_finish_date',
                       'actual_start_date', 'actual_finish_date',
@@ -252,7 +251,7 @@ class Work(ModelSQL, ModelView):
                         db_field: value \
                                 and datetime.datetime.combine(value,
                                     datetime.time()) \
-                                or False,
+                                or None,
                         })
                 break
 
@@ -277,10 +276,8 @@ class Work(ModelSQL, ModelView):
         return date
 
     def add_hours(self, company, date, hours):
-        day_per_week = company.hours_per_work_week / company.hours_per_work_day
-
         while hours:
-            if hours !=  intfloor(hours):
+            if hours != intfloor(hours):
                 minutes = (hours - intfloor(hours)) * 60
                 date = self.add_minutes(company, date, minutes)
             hours = intfloor(hours)
@@ -308,7 +305,7 @@ class Work(ModelSQL, ModelView):
         day_per_week = company.hours_per_work_week / company.hours_per_work_day
 
         while days:
-            if days !=  intfloor(days):
+            if days != intfloor(days):
                 hours = (days - intfloor(days)) * company.hours_per_work_day
                 date = self.add_hours(company, date, hours)
             days = intfloor(days)
@@ -321,7 +318,7 @@ class Work(ModelSQL, ModelView):
             if weeks:
                 date = self.add_weeks(company, date, weeks)
 
-            date += datetime.timedelta(days= -date.weekday() + intfloor(days))
+            date += datetime.timedelta(days=-date.weekday() + intfloor(days))
 
             days = days - intfloor(days)
 
@@ -330,12 +327,12 @@ class Work(ModelSQL, ModelView):
     def add_weeks(self, company, date, weeks):
         day_per_week = company.hours_per_work_week / company.hours_per_work_day
 
-        if weeks !=  intfloor(weeks):
+        if weeks != intfloor(weeks):
             days = (weeks - intfloor(weeks)) * day_per_week
             if days:
                 date = self.add_days(company, date, days)
 
-        date += datetime.timedelta(days= 7 * intfloor(weeks))
+        date += datetime.timedelta(days=7 * intfloor(weeks))
 
         return date
 
@@ -346,9 +343,8 @@ class Work(ModelSQL, ModelView):
             'early_finish_time', work['early_finish_time'])
         get_late_start = lambda work: values.get(work, {}).get(
             'late_start_time', work['late_start_time'])
-        maxdate = lambda x,y: x and y and max(x,y) or x or y
-        mindate = lambda x,y: x and y and min(x,y) or x or y
-
+        maxdate = lambda x, y: x and y and max(x, y) or x or y
+        mindate = lambda x, y: x and y and min(x, y) or x or y
 
         # propagate constraint_start_time
         constraint_start = reduce(maxdate, (pred.early_finish_time \
@@ -529,7 +525,7 @@ class Work(ModelSQL, ModelView):
                              set(s.id for s in w.successors))
 
         work = self.browse(work_id)
-        parent_id = work.parent and work.parent.id or False
+        parent_id = work.parent and work.parent.id or None
         sibling_ids = self.search([
                 ('parent', '=', parent_id)
                 ])
@@ -553,11 +549,13 @@ class Work(ModelSQL, ModelView):
         # define some helper functions
         get_key = lambda w: (set(p.id for p in w.predecessors),
                              set(s.id for s in w.successors))
-        over_alloc = lambda current_alloc, work: \
-            reduce(lambda res, alloc: res or current_alloc[alloc.employee.id] + \
-                       alloc.percentage > 100,
-                   work.allocations,
-                   False)
+        over_alloc = lambda current_alloc, work: (
+            reduce(lambda res, alloc: (res
+                    or (current_alloc[alloc.employee.id]
+                        + alloc.percentage) > 100),
+                work.allocations,
+                False))
+
         def sum_allocs(current_alloc, work):
             res = defaultdict(float)
             for alloc in work.allocations:
@@ -604,13 +602,14 @@ class Work(ModelSQL, ModelView):
                 yield sibling, delay
 
         work = self.browse(work_id)
-        parent_id = work.parent and work.parent.id or False
+        parent_id = work.parent and work.parent.id or None
         sibling_ids = self.search([
                 ('parent', '=', parent_id)
                 ])
 
         refkey = get_key(work)
-        siblings = [s for s in self.browse(sibling_ids) if get_key(s) == refkey]
+        siblings = [s for s in self.browse(sibling_ids)
+            if get_key(s) == refkey]
 
         for sibling, delay in compute_delays(siblings):
             self.write(sibling.id, {
@@ -636,7 +635,7 @@ class Work(ModelSQL, ModelView):
                 self.reset_leveling(work_id)
         fields = ('constraint_start_time', 'constraint_finish_time',
                   'effort')
-        if reduce(lambda x, y : x or y in values, fields, False):
+        if reduce(lambda x, y: x or y in values, fields, False):
             for work_id in ids:
                 self.compute_dates(work_id)
         return res
@@ -667,16 +666,15 @@ class Work(ModelSQL, ModelView):
 Work()
 
 
-
 class PredecessorSuccessor(ModelSQL):
     'Predecessor - Successor'
     _name = 'project.predecessor_successor'
     _description = __doc__
 
     predecessor = fields.Many2One('project.work', 'Predecessor',
-            ondelete='CASCADE', required=True, select=1)
+            ondelete='CASCADE', required=True, select=True)
     successor = fields.Many2One('project.work', 'Successor',
-            ondelete='CASCADE', required=True, select=1)
+            ondelete='CASCADE', required=True, select=True)
 
     def write(self, ids, values):
         work_obj = Pool().get('project.work')
@@ -731,20 +729,12 @@ PredecessorSuccessor()
 class Leveling(Wizard):
     'Tasks Leveling'
     _name = 'project_plan.work.leveling'
+    start_state = 'leveling'
+    leveling = StateTransition()
 
-    states = {
-        'init': {
-            'result': {
-                'type': 'action',
-                'action': '_leveling',
-                'state': 'end',
-                },
-            },
-        }
-
-    def _leveling(self, data):
+    def transition_leveling(self, session):
         work_obj = Pool().get('project.work')
-        work_obj.create_leveling(data['id'])
-        return {}
+        work_obj.create_leveling(Transaction().context['active_id'])
+        return 'end'
 
 Leveling()
